import type { Configuration, IgnorePatterns, WorkspaceConfiguration } from './types/config.js';
import type { PackageJson } from './types/package-json.js';
import { type Graph } from './util/pkgs-graph.js';
type ConfigurationManagerOptions = {
    cwd: string;
    isProduction: boolean;
    isStrict: boolean;
    isIncludeEntryExports: boolean;
};
export type Package = {
    dir: string;
    name: string;
    pkgName: string | undefined;
    manifest: PackageJson;
};
export type Workspace = {
    name: string;
    pkgName: string;
    dir: string;
    ancestors: string[];
    config: WorkspaceConfiguration;
    manifestPath: string;
    ignoreMembers: IgnorePatterns;
    srcDir?: string;
    outDir?: string;
};
export declare class ConfigurationChief {
    cwd: string;
    isProduction: boolean;
    isStrict: boolean;
    isIncludeEntryExports: boolean;
    config: Configuration;
    manifestPath?: string;
    manifest?: PackageJson;
    ignoredWorkspacePatterns: string[];
    workspacePackages: any;
    workspacePackagesByName: any;
    additionalWorkspaceNames: any;
    availableWorkspaceNames: string[];
    availableWorkspacePkgNames: any;
    availableWorkspaceDirs: string[];
    packageGraph: Graph | undefined;
    includedWorkspaces: Workspace[];
    resolvedConfigFilePath?: string;
    rawConfig?: any;
    constructor({ cwd, isProduction, isStrict, isIncludeEntryExports }: ConfigurationManagerOptions);
    init(): any;
    private loadResolvedConfigurationFile;
    getRules(): Record<keyof import("./types/issues.js").Issues, import("./types/issues.js").IssueSeverity>;
    getFilters(): {
        dir: string;
    } | {
        dir?: undefined;
    };
    private normalize;
    private setWorkspaces;
    private addRootPackage;
    private getListedWorkspaces;
    private getIgnoredWorkspacePatterns;
    private getConfiguredWorkspaceKeys;
    private getAdditionalWorkspaceNames;
    private getAvailableWorkspaceNames;
    private getAvailableWorkspacePkgNames;
    private determineIncludedWorkspaces;
    getManifestForWorkspace(name: string): any;
    getIncludedWorkspaces(): Workspace[];
    private getDescendentWorkspaces;
    private getIgnoredWorkspacesFor;
    getNegatedWorkspacePatterns(name: string): any;
    private getConfigKeyForWorkspace;
    getWorkspaceConfig(workspaceName: string): any;
    getIgnores(workspaceName: string): {
        ignoreBinaries: any;
        ignoreDependencies: any;
    };
    getConfigForWorkspace(workspaceName: string, extensions?: string[]): any;
    getIncludedIssueTypes(): any;
    findWorkspaceByFilePath(filePath: string): any;
    findWorkspaceByName(name: string): any;
    getUnusedIgnoredWorkspaces(): any;
}
export {};
